import platform
from glob import glob
from setuptools import setup, find_packages
from pybind11 import get_include
from pybind11.setup_helpers import Pybind11Extension, build_ext


__version__ = '1.0.0'

# for libLEPC2 / LEPCLIB_RT2 library
include_dirs = [get_include(), 'lepcpy']
library_dirs = []
libraries = []

# for Windows DLL
package_include = ['lepcpy']
package_data = {'lepcpy': []}

match platform.architecture():
    case ('32bit', 'WindowsPE'):  # Windows
        library_dirs.append('lepcpy')
        libraries.append('LEPCLIB_RT2')
        package_data['lepcpy'].append('*.dll')

    case _:  # Linux
        libraries.append('LEPC2')

ext_modules = [
    Pybind11Extension(
        'lepcpy.bindings',
        sources=sorted(glob('lepcpy/*.cc')),
        include_dirs=include_dirs,
        library_dirs=library_dirs,
        libraries=libraries,
        define_macros=[('VERSION_INFO', __version__)],
    ),
]

setup(
    name='lepcpy',
    version=__version__,
    author='LINEEYE CO., LTD',
    url='https://www.lineeye.co.jp/',
    description='A wrapper example of libLEPC2 (Linux) / LEPCLIB_RT2 (Windows)',
    long_description='',
    zip_safe=False,
    include_package_data=True,
    packages=find_packages(include=['lepcpy']),
    package_data=package_data,
    ext_modules=ext_modules,
    extras_require={'test': 'pytest'},
    cmdclass={'build_ext': build_ext},
    install_requires=['numpy'],
    python_requires='>=3.7',
)
